@@ -26,18 +26,3 @@ class InternalToken(Serializable):
     @property
     def is_expired(self) -> bool:
         return self.expires < datetime.now(tz=timezone.utc)
-
-
-# -- Delegates ---------------------------------------------------------------
-
-
-@dataclass
-class MeteringPointDelegate(Serializable):
-    """
-    An actor (identified by its subject) who has been delegated
-    access to a MeteringPoint (identified by its GSRN number).
-    """
-    subject: str
-    gsrn: str
-
-    # TODO Define time period (???)
